/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */

/**
Create a Tags object.
Saves the state of the Show Tags button in an editable target.

@constructor
*/
function MozileTags( active ) {
	this.active = active || false;
	this.setActive = mozileTagButton;
}

/**
Creates a link to a special stylesheet, or removes it.

<p>The default XHTML style sheet highlights XHTML tags.
<p>An alternate style sheet (e.g. for XML files) can be specified via the RSD configuration file.
*/
function mozileShowHideTags() {
	var f = ["mozileCommands.js","mozileShowHideTags"];

	var target = mozileGetCurrentTarget();
	if (!target) {
		target = document.commandDispatcher.focusedWindow;
	}else if (target != document.commandDispatcher.focusedWindow) {
		return;
	}

	if ( !mozileIsLoaded( target ) ) {
		return;
	}

	var targetDoc = target.document;
	var head = targetDoc.getElementsByTagName("head")[0];
	var id = "mozile-show-tags";
	var link = targetDoc.getElementById(id);
	var tagCSS = targetDoc.MOZILE_RSD_CONFIG.tagCSS;
	var href;

	if(tagCSS=="XHTML" || !tagCSS || tagCSS=="") {
		href = MOZILEC.TAGS_XHTML;
	} else {
		href = tagCSS;
	}
	
	if(!head) {
		head = targetDoc.documentElement;
		mozileDebug(f,2,"Document element: "+head.tagName);
	}

	if(link) {
		head.removeChild(link);
		mozileTagButton(target,false);
		mozileDebug(f,2,"Hide tags");
	} else {
		link = document.createElementNS(MOZILEC.NAMESPACE_XHTML,"link");
		link.id = id;
		link.setAttribute("rel","stylesheet");
		link.setAttribute("type","text/css");
		link.setAttribute("href",href);
		head.appendChild(link);
		mozileTagButton(target,true);
		mozileDebug(f,2,"Show tags");
	}
}

/**
Sets the <code>active</code> attribute of the Tag-view button.

@param target - target window (target MUST be valid.)
@param {boolean} active true means button "pressed in."
*/
function mozileTagButton( target, active ) {
	if (active) {
		mozileTools.buttonTags.setAttribute("active","true");
		target.mozileTags.active=true;
	} else {
		mozileTools.buttonTags.setAttribute("active","false");
		target.mozileTags.active=false;
	}
}

